<?php

namespace Drupal\eaf\Plugin\EntityAttribute;

use Drupal\eaf\Annotation\EntityAttribute;
use Drupal\eaf\EntityAttributePluginBase;

/**
 * Plugin implementation of the 'full-width' modifier setting.
 *
 * @EntityAttribute(
 *   id = "full_width",
 *   label = @Translation("Full width"),
 *   settings = {
 *      "parent" = "entity_class",
 *      "weight" = 10,
 *   }
 * )
 */
class FullWidth extends EntityAttributePluginBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(): array {
    $element = parent::formElement();

    return [
      '#type' => 'checkbox',
      '#description' => $this->t('Stretch this paragraph to 100% browser width.'),
    ] + $element;
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultValue(): mixed {
    return 0;
  }

  /**
   * {@inheritdoc}
   */
  public function setValue($value, $values, $section = NULL): array {
    $values = parent::setValue($value, $values, $section);
    if ($value) {
      // @todo The common classes name -> do we need this?
      // Add somewhere in a preprocess - it is a theme dependent!
      $values['classes'][] = 'full-width';
    }
    return $values;
  }

}
